==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PrzypomnienieKonfiguracjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.GrupaZadania;
import pl.topteam.dps.enums.TypDanychPrzypomnienie;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class PrzypomnienieKonfiguracjaKey extends GenericDPSObject {
    /**
     * PRZYPOMNIENIE_KONFIGURACJA.JOB_NAME
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String jobName;

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.JOB_GROUP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private GrupaZadania jobGroup;

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.TYP_DANYCH
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypDanychPrzypomnienie typDanych;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PRZYPOMNIENIE_KONFIGURACJA.JOB_NAME
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getJobName() {
        return jobName;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.JOB_NAME
     *
     * @param jobName
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setJobName(String jobName) {
        this.jobName = jobName == null ? null : jobName.trim();
    }

    /**
     * @return PRZYPOMNIENIE_KONFIGURACJA.JOB_GROUP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public GrupaZadania getJobGroup() {
        return jobGroup;
    }

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.JOB_GROUP
     *
     * @param jobGroup
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setJobGroup(GrupaZadania jobGroup) {
        this.jobGroup = jobGroup;
    }

    /**
     * @return PRZYPOMNIENIE_KONFIGURACJA.TYP_DANYCH
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypDanychPrzypomnienie getTypDanych() {
        return typDanych;
    }

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.TYP_DANYCH
     *
     * @param typDanych
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTypDanych(TypDanychPrzypomnienie typDanych) {
        this.typDanych = typDanych;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PrzypomnienieKonfiguracjaKey other = (PrzypomnienieKonfiguracjaKey) that;
        return (this.getJobName() == null ? other.getJobName() == null : this.getJobName().equals(other.getJobName()))
            && (this.getJobGroup() == null ? other.getJobGroup() == null : this.getJobGroup().equals(other.getJobGroup()))
            && (this.getTypDanych() == null ? other.getTypDanych() == null : this.getTypDanych().equals(other.getTypDanych()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getJobName() == null) ? 0 : getJobName().hashCode());
        result = prime * result + ((getJobGroup() == null) ? 0 : getJobGroup().hashCode());
        result = prime * result + ((getTypDanych() == null) ? 0 : getTypDanych().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", jobName=").append(jobName);
        sb.append(", jobGroup=").append(jobGroup);
        sb.append(", typDanych=").append(typDanych);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PrzypomnienieKonfiguracjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.GrupaZadania;
import pl.topteam.dps.enums.TypDanychPrzypomnienie;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class PrzypomnienieKonfiguracjaKey extends GenericDPSObject {
    /**
     * PRZYPOMNIENIE_KONFIGURACJA.JOB_NAME
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String jobName;

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.JOB_GROUP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private GrupaZadania jobGroup;

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.TYP_DANYCH
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypDanychPrzypomnienie typDanych;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PRZYPOMNIENIE_KONFIGURACJA.JOB_NAME
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getJobName() {
        return jobName;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.JOB_NAME
     *
     * @param jobName
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setJobName(String jobName) {
        this.jobName = jobName == null ? null : jobName.trim();
    }

    /**
     * @return PRZYPOMNIENIE_KONFIGURACJA.JOB_GROUP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public GrupaZadania getJobGroup() {
        return jobGroup;
    }

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.JOB_GROUP
     *
     * @param jobGroup
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setJobGroup(GrupaZadania jobGroup) {
        this.jobGroup = jobGroup;
    }

    /**
     * @return PRZYPOMNIENIE_KONFIGURACJA.TYP_DANYCH
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypDanychPrzypomnienie getTypDanych() {
        return typDanych;
    }

    /**
     * PRZYPOMNIENIE_KONFIGURACJA.TYP_DANYCH
     *
     * @param typDanych
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTypDanych(TypDanychPrzypomnienie typDanych) {
        this.typDanych = typDanych;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PrzypomnienieKonfiguracjaKey other = (PrzypomnienieKonfiguracjaKey) that;
        return (this.getJobName() == null ? other.getJobName() == null : this.getJobName().equals(other.getJobName()))
            && (this.getJobGroup() == null ? other.getJobGroup() == null : this.getJobGroup().equals(other.getJobGroup()))
            && (this.getTypDanych() == null ? other.getTypDanych() == null : this.getTypDanych().equals(other.getTypDanych()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getJobName() == null) ? 0 : getJobName().hashCode());
        result = prime * result + ((getJobGroup() == null) ? 0 : getJobGroup().hashCode());
        result = prime * result + ((getTypDanych() == null) ? 0 : getTypDanych().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", jobName=").append(jobName);
        sb.append(", jobGroup=").append(jobGroup);
        sb.append(", typDanych=").append(typDanych);
        sb.append("]");
        return sb.toString();
    }
}
